@@ -43,7 +43,7 @@
 #define NMV_GENERAL_DOMAIN "general-domain"
 #endif
 
-using std::string ;
+using std::string;
 namespace nemiver {
 namespace common {
 
@@ -53,14 +53,14 @@ namespace common {
 class NEMIVER_API LogStream
 {
     friend LogStream& timestamp (LogStream &);
-    friend LogStream& flush (LogStream &) ;
-    friend LogStream& endl (LogStream &) ;
-    struct Priv ;
-    SafePtr<Priv> m_priv ;
+    friend LogStream& flush (LogStream &);
+    friend LogStream& endl (LogStream &);
+    struct Priv;
+    SafePtr<Priv> m_priv;
 
     //forbid copy/assignation
-    LogStream (LogStream const&) ;
-    LogStream& operator= (LogStream const&) ;
+    LogStream (LogStream const&);
+    LogStream& operator= (LogStream const&);
 
 protected:
 
@@ -84,11 +84,11 @@ public:
     ///(either cout, cerr, or log file). By default, the type of stream is
     /// set to COUT_STREAM. All the logs are sent to stdout.
     /// \param a_type the type of the log stream
-    static void set_stream_type (enum StreamType a_type) ;
+    static void set_stream_type (enum StreamType a_type);
 
     /// \brief gets the type of the instances of #LogStream
     /// \return the stream type as set by LogStream::set_stream_type().
-    static enum StreamType get_stream_type () ;
+    static enum StreamType get_stream_type ();
 
     /// in the case where the stream type is set to FILE_STREAM,
     /// this methods sets the path of the file to log into. By default,
@@ -96,12 +96,12 @@ public:
     /// \param a_file_path the log file path.
     /// \param a_len the length of the file_path. If <0, it means that a_file_path
     /// is a zero terminated string.
-    static void set_stream_file_path (const char* a_file_path, long a_len=-1) ;
+    static void set_stream_file_path (const char* a_file_path, long a_len=-1);
 
     /// \brief gets the log file path, in case the stream type is set to
     /// FILE_STREAM
     /// \return the path to the log file.
-    static const char* get_stream_file_path () ;
+    static const char* get_stream_file_path ();
 
     /// \brief sets the log level filter.
     /// if the filter is set to LOG_LEVEL_NORMAL, only the log streams that
@@ -111,7 +111,7 @@ public:
     /// logging data.
     ///
     /// \param a_level the level of verbosity you want your log streams to have.
-    static void set_log_level_filter (enum LogLevel a_level) ;
+    static void set_log_level_filter (enum LogLevel a_level);
 
     /// \brief sets a filter on the log domain
     /// only streams that have the same domain as the one set here will
@@ -119,21 +119,21 @@ public:
     /// \param a_domain the domain name.
     /// \a_len the length of the domain name. If <0, it means that a_domain
     /// is a zero terminated string.
-    static void set_log_domain_filter (const char* a_domain, long a_len=-1) ;
+    static void set_log_domain_filter (const char* a_domain, long a_len=-1);
 
     /// \brief activate/de-activate the logging.
     /// \param a_activate true to activate the logging, false to deactivate.
-    static void activate (bool a_activate) ;
+    static void activate (bool a_activate);
 
     /// \brief tests wether the logging is activated or not.
     /// \return true if the logging is activated, false otherwise.
-    static bool is_active () ;
+    static bool is_active ();
 
     /// \brief gets the log stream instanciated by the system by default.
     /// the options of this log stream are the global options set before
     /// the first call to this method.
     /// \return the log stream instanciated by default.
-    static LogStream& default_log_stream () ;
+    static LogStream& default_log_stream ();
 
 
     /// \brief default constructor of a log stream
@@ -144,20 +144,20 @@ public:
     /// its log level is <= to the log level filter, *and* if its domain equals
     /// the domain filter.
     LogStream (enum LogLevel a_level=LOG_LEVEL_NORMAL,
-               const string &a_default_domain=NMV_GENERAL_DOMAIN) ;
+               const string &a_default_domain=NMV_GENERAL_DOMAIN);
 
     /// \brief destructor of the log stream class
-    virtual ~LogStream () ;
+    virtual ~LogStream ();
 
     /// \brief enable or disable logging for a domain
     /// \param a_domain the domain to enable logging for
     /// \param a_do_enable when set to true, enables the logging for domain
     /// @a_domain, disable it otherwise.
     void enable_domain (const string &a_domain,
-                        bool a_do_enable=true) ;
+                        bool a_do_enable=true);
 
     /// \return true is logging is enabled for domain @a_domain
-    bool is_domain_enabled (const string &a_domain) ;
+    bool is_domain_enabled (const string &a_domain);
 
     /// \brief writes a text string to the stream
     /// \param a_buf the buffer that contains the text string.
@@ -166,83 +166,91 @@ public:
     /// \param a_domain the domain the string has to be logged against.
     LogStream& write (const char *a_buf,
                       long a_buflen =-1,
-                      const string &a_domain=NMV_GENERAL_DOMAIN) ;
+                      const string &a_domain=NMV_GENERAL_DOMAIN);
 
     /// \brief log a message to the stream
     /// \param a_msg the message to log
     /// \param a_domain the domain to log against
-    LogStream& write (const UString &a_msg,
-                      const string &a_domain=NMV_GENERAL_DOMAIN) ;
+    LogStream& write (const Glib::ustring &a_msg,
+                      const string &a_domain=NMV_GENERAL_DOMAIN);
 
     LogStream& write (int a_msg,
-                      const string &a_domain=NMV_GENERAL_DOMAIN) ;
+                      const string &a_domain=NMV_GENERAL_DOMAIN);
 
     LogStream& write (double a_msg,
-                      const string &a_domain=NMV_GENERAL_DOMAIN) ;
+                      const string &a_domain=NMV_GENERAL_DOMAIN);
 
     LogStream& write (char a_msg,
-                      const string &a_domain=NMV_GENERAL_DOMAIN) ;
+                      const string &a_domain=NMV_GENERAL_DOMAIN);
 
     /// set the domain in against which all the coming
     /// messages will be logged.
     /// This is to be used in association with the << operators where
     /// we cannot specify the domain to log against, unlike LogStream::write() .
     /// \param a_domain the domain to log against.
-    void push_domain (const string &a_domain) ;
+    void push_domain (const string &a_domain);
 
     /// pops the last domain that has been pushed using LogStream::push_domain.
-    void pop_domain () ;
+    void pop_domain ();
 
     /// \brief log zero teriminated strings
     /// \param a_string the string to log
-    LogStream& operator<< (const UString &a_string) ;
+    LogStream& operator<< (const char* a_c_string);
+
+    /// \brief log a string
+    /// \param a_string the string to log
+    LogStream& operator<< (const std::string &a_string);
+
+    /// \brief log a UTF-8 string
+    /// \param a_string the string to log
+    LogStream& operator<< (const Glib::ustring &a_string);
 
     /// \brief log an integer
     /// \param an_int the integer to log
-    LogStream& operator<< (int an_int) ;
+    LogStream& operator<< (int an_int);
 
     /// \brief log a double
     /// \param the double to log
-    LogStream& operator<< (double a_double) ;
+    LogStream& operator<< (double a_double);
 
     /// \brief log a character
     /// \param a_char the char to log
-    LogStream& operator<< (char a_char) ;
+    LogStream& operator<< (char a_char);
 
     /// \brief  log a stream manipulator
     /// \param a_manipulator the LogStream manipulator to log
-    LogStream& operator<< (LogStream& (*a_manipulator) (LogStream&)) ;
+    LogStream& operator<< (LogStream& (*a_manipulator) (LogStream&));
 
-    friend LogStream& level_normal (LogStream &a_stream) ;
+    friend LogStream& level_normal (LogStream &a_stream);
 
-    friend LogStream& level_verbose (LogStream &a_stream) ;
+    friend LogStream& level_verbose (LogStream &a_stream);
 
 };//end class LogStream
 
 /// \brief logs a timestamp. Basically the
 /// the current date. You use it like:
-/// nemiver::LogStream out ; out << nemiver::timestamp ;
+/// nemiver::LogStream out; out << nemiver::timestamp ;
 NEMIVER_API LogStream& timestamp (LogStream&);
 
 /// \brief flushes the stream
-/// Use it like: nemiver::LogStream out ;
-/// out << "Hello" << nemiver::flush ;
-NEMIVER_API LogStream& flush (LogStream &) ;
+/// Use it like: nemiver::LogStream out;
+/// out << "Hello" << nemiver::flush;
+NEMIVER_API LogStream& flush (LogStream &);
 
 /// \brief log a '\\n' and flushes the stream
-/// Use it like: nemiver::LogStream out ;
-/// out << "hello"<< nemiver::endl ;
-NEMIVER_API LogStream& endl (LogStream &) ;
+/// Use it like: nemiver::LogStream out;
+/// out << "hello"<< nemiver::endl;
+NEMIVER_API LogStream& endl (LogStream &);
 
 /// \brief sets the log level to normal
-/// Use it like nemiver::LogStream out ;
-/// out << nemiver::level_normal << "blabla" ;
-NEMIVER_API LogStream& level_normal (LogStream &) ;
+/// Use it like nemiver::LogStream out;
+/// out << nemiver::level_normal << "blabla";
+NEMIVER_API LogStream& level_normal (LogStream &);
 
 /// \brief sets the log level to verbose
-/// Use it lik: nemiver::LogStream out ;
-/// out << nemiver::level_verbose << "bla bla bla" ;
-NEMIVER_API LogStream& level_verbose (LogStream &) ;
+/// Use it lik: nemiver::LogStream out;
+/// out << nemiver::level_verbose << "bla bla bla";
+NEMIVER_API LogStream& level_verbose (LogStream &);
 
 }//end namespace common
 }//end namespace nemiver
