@@ -23,6 +23,7 @@
  *See COPYRIGHT file copyright information.
  */
 #include <signal.h>
+#include <unistd.h>
 #include <iostream>
 #include <gtkmm/window.h>
 #include <libglademm.h>
@@ -55,6 +56,7 @@ static bool gv_last_session=false;
 static gchar *gv_log_domains=0;
 static bool gv_log_debugger_output=false;
 static bool gv_show_version=false;
+static bool gv_use_launch_terminal=false;
 
 static GOptionEntry entries[] =
 {
@@ -76,7 +78,7 @@ static GOptionEntry entries[] =
       _("Attach to a process"),
       "<pid|process name>"
     },
-    { "listsessions",
+    { "list-sessions",
       0,
       0,
       G_OPTION_ARG_NONE,
@@ -84,7 +86,7 @@ static GOptionEntry entries[] =
       _("List the saved debugging sessions"),
       NULL
     },
-    { "purgesessions",
+    { "purge-sessions",
       0,
       0,
       G_OPTION_ARG_NONE,
@@ -116,7 +118,7 @@ static GOptionEntry entries[] =
       _("Enable logging domains DOMAINS"),
       "DOMAINS"
     },
-    { "logdebuggeroutput",
+    { "log-debugger-output",
       0,
       0,
       G_OPTION_ARG_NONE,
@@ -124,6 +126,14 @@ static GOptionEntry entries[] =
       _("Log the debugger output"),
       NULL
     },
+    { "use-launch-terminal",
+      0,
+      0,
+      G_OPTION_ARG_NONE,
+      &gv_use_launch_terminal,
+      _("Use this terminal as the debugee's terminal"),
+      NULL
+    },
     { "version",
       0,
       0,
@@ -204,24 +214,61 @@ init_option_context ()
     g_option_context_add_main_entries (context.get (),
                                        entries,
                                        GETTEXT_PACKAGE);
-    g_option_context_set_ignore_unknown_options (context.get (), true);
+    g_option_context_set_ignore_unknown_options (context.get (), false);
     GOptionGroupSafePtr gtk_option_group (gtk_get_option_group (FALSE));
     THROW_IF_FAIL (gtk_option_group);
     g_option_context_add_group (context.get (), gtk_option_group.release ());
     return context.release ();
 }
 
+// Parse the command line and edits it
+// to make it contain the command line of the inferior program.
 static void
 parse_command_line (int& a_argc,
                     char** a_argv)
 {
     GOptionContextSafePtr context (init_option_context ());
     THROW_IF_FAIL (context);
-    g_option_context_parse (context.get (), &a_argc, &a_argv, 0);
+
+    if (a_argc == 1) {
+        // We have no inferior program so edit the command like accordingly.
+        a_argc = 0;
+        a_argv[0] = 0;
+        return;
+    }
+
+    // Split the command like in two parts. One part is made of the options
+    // for Nemiver itself, and the other part is the options relevant to
+    // the inferior.
+    int i;
+    std::vector<UString> args;
+    for (i = 1; i < a_argc; ++i)
+        if (a_argv[i][0] != '-')
+            break;
+
+    // Now parse only the part of the command line that is related
+    // to Nemiver and not to the inferior.
+    // Once parsed, make a_argv and a_argv contain the command line
+    // of the inferior.
+    char **nmv_argv, **inf_argv;
+    int nmv_argc = a_argc;
+    int inf_argc = 0;
+
+    if (i < a_argc) {
+        nmv_argc = i;
+        inf_argc = a_argc - i;
+    }
+    nmv_argv = a_argv;
+    inf_argv = a_argv + i;
+    g_option_context_parse (context.get (), &nmv_argc, &nmv_argv, 0);
+    if (a_argv != inf_argv) {
+        memmove (a_argv, inf_argv, inf_argc * sizeof (char*));
+        a_argc = inf_argc;
+    }
 }
 
 static bool
-process_non_gui_command_line (int&, char**, int &a_return)
+process_non_gui_options ()
 {
     if (gv_log_debugger_output) {
         LOG_STREAM.enable_domain ("gdbmi-output-domain");
@@ -241,13 +288,11 @@ process_non_gui_command_line (int&, char**, int &a_return)
             LOG_STREAM.enable_domain (*iter);
         }
     }
-
-    a_return = 0;
     return true;
 }
 
 static bool
-process_gui_command_line (int& a_argc, char** a_argv, int &a_return)
+process_gui_options (int& a_argc, char** a_argv)
 {
     if (gv_purge_sessions) {
         IDBGPerspective *debug_persp =
@@ -256,7 +301,6 @@ process_gui_command_line (int& a_argc, char** a_argv, int &a_return)
         if (debug_persp) {
             debug_persp->session_manager ().delete_sessions ();
         }
-        a_return = 0;
         return false;
     }
 
@@ -269,7 +313,6 @@ process_gui_command_line (int& a_argc, char** a_argv, int &a_return)
                                                 (DBGPERSPECTIVE_PLUGIN_NAME));
         if (!debug_persp) {
             cerr << "Could not get the debugging perspective" << endl;
-            a_return = -1;
             return false;
         }
         int pid = atoi (gv_process_to_attach_to);
@@ -277,7 +320,6 @@ process_gui_command_line (int& a_argc, char** a_argv, int &a_return)
             IProcMgrSafePtr proc_mgr = IProcMgr::create ();
             if (!proc_mgr) {
                 cerr << "Could not create proc mgr" << endl;
-                a_return = -1;
                 return false;
             }
             IProcMgr::Process process;
@@ -286,9 +328,7 @@ process_gui_command_line (int& a_argc, char** a_argv, int &a_return)
                 cerr << "Could not find any process named '"
                 << gv_process_to_attach_to
                 << "'"
-                << endl
-               ;
-                a_return = -1;
+                << endl;
                 return false;
             }
             pid = process.pid ();
@@ -297,11 +337,10 @@ process_gui_command_line (int& a_argc, char** a_argv, int &a_return)
             cerr << "Could not find any process '"
                  << gv_process_to_attach_to
                  << "'"
-                 << endl
-                ;
-            a_return = -1;
+                 << endl;
             return false;
         } else {
+            debug_persp->uses_launch_terminal (gv_use_launch_terminal);
             debug_persp->attach_to_program (pid);
         }
     }
@@ -323,11 +362,9 @@ process_gui_command_line (int& a_argc, char** a_argv, int &a_return)
                      << session_iter->properties ()["sessionname"]
                      << "\n";
             }
-            a_return = 0;
             return false;
         } else {
             cerr << "Could not find the debugger perpective plugin";
-            a_return = -1;
             return false;
         }
     }
@@ -342,6 +379,7 @@ process_gui_command_line (int& a_argc, char** a_argv, int &a_return)
             list<ISessMgr::Session>& sessions =
                             debug_persp->session_manager ().sessions ();
             bool found_session=false;
+            debug_persp->uses_launch_terminal (gv_use_launch_terminal);
             for (session_iter = sessions.begin ();
                  session_iter != sessions.end ();
                  ++session_iter) {
@@ -356,7 +394,6 @@ process_gui_command_line (int& a_argc, char** a_argv, int &a_return)
                 cerr << "Could not find session of number "
                      << gv_execute_session
                      << "\n";
-                a_return = -1;
                 return false;
             }
             return true;
@@ -373,6 +410,7 @@ process_gui_command_line (int& a_argc, char** a_argv, int &a_return)
             list<ISessMgr::Session>& sessions =
                             debug_persp->session_manager ().sessions ();
             if (!sessions.empty ()) {
+                debug_persp->uses_launch_terminal (gv_use_launch_terminal);
                 list<ISessMgr::Session>::iterator session_iter,
                     latest_session_iter;
                 glong time_val = 0;
@@ -393,55 +431,54 @@ process_gui_command_line (int& a_argc, char** a_argv, int &a_return)
             } else {
                 cerr << "Could not find any sessions"
                      << "\n";
-                a_return = -1;
                 return false;
             }
             return true;
         }
     }
 
-    if (a_argc > 1) {
-        if (a_argv[1][0] == '-') {
-            std::cerr << "unknown option " << a_argv[1] << "\n";
-            a_return = 0;
-            return false;
-        }
-        vector<UString> prog_args;
-        UString prog_path = a_argv[1];
-        for (int i=2; i < a_argc; ++i) {
-            prog_args.push_back (Glib::locale_to_utf8 (a_argv[i]));
-        }
-        IDBGPerspective *debug_persp =
-            dynamic_cast<IDBGPerspective*> (s_workbench->get_perspective
-                                                (DBGPERSPECTIVE_PLUGIN_NAME));
-        if (debug_persp) {
-            map<UString, UString> env;
-            if (gv_env_vars) {
-                vector<UString> env_vars =
-                    UString (Glib::locale_to_utf8 (gv_env_vars)).split (" ");
-                for (vector<UString>::const_iterator it = env_vars.begin ();
-                     it != env_vars.end ();
-                     ++it) {
-                    vector<UString> env_var = it->split ("=");
-                    if (env_var.size () != 2) {
-                        continue;
-                    }
-                    UString name = env_var[0];
-                    name.chomp ();
-                    UString value = env_var[1];
-                    value.chomp ();
-                    LOG_DD ("got env var: " << name << "=" << value);
-                    env[name] = value;
+    vector<UString> prog_args;
+    UString prog_path;
+    // Here, a_argc is the argument count of the inferior program.
+    // It's zero if there is there is no inferior program.
+    // Otherwise it equals the number of arguments to the inferior program + 1
+    if (a_argc > 0)
+        prog_path = a_argv[0];
+    for (int i = 1; i < a_argc; ++i) {
+        prog_args.push_back (Glib::locale_to_utf8 (a_argv[i]));
+    }
+    IDBGPerspective *debug_persp =
+        dynamic_cast<IDBGPerspective*> (s_workbench->get_perspective
+                                            (DBGPERSPECTIVE_PLUGIN_NAME));
+    if (debug_persp) {
+        map<UString, UString> env;
+        if (gv_env_vars) {
+            vector<UString> env_vars =
+                UString (Glib::locale_to_utf8 (gv_env_vars)).split (" ");
+            for (vector<UString>::const_iterator it = env_vars.begin ();
+                 it != env_vars.end ();
+                 ++it) {
+                vector<UString> env_var = it->split ("=");
+                if (env_var.size () != 2) {
+                    continue;
                 }
+                UString name = env_var[0];
+                name.chomp ();
+                UString value = env_var[1];
+                value.chomp ();
+                LOG_DD ("got env var: " << name << "=" << value);
+                env[name] = value;
             }
+        }
+        if (!prog_path.empty ()) {
+            debug_persp->uses_launch_terminal (gv_use_launch_terminal);
             debug_persp->execute_program (prog_path,
                                           prog_args,
                                           env);
-        } else {
-            cerr << "Could not find the debugger perspective plugin\n";
-            a_return = -1;
-            return false;
         }
+    } else {
+        cerr << "Could not find the debugger perspective plugin\n";
+        return false;
     }
     return true;
 }
@@ -460,12 +497,10 @@ main (int a_argc, char *a_argv[])
 
     parse_command_line (a_argc, a_argv);
 
-    int retval;
-    if (process_non_gui_command_line (a_argc, a_argv, retval) != true) {
+    if (process_non_gui_options () != true) {
         return -1;
     }
 
-
     //********************************************
     //load and init the workbench dynamic module
     //********************************************
@@ -481,12 +516,38 @@ main (int a_argc, char *a_argv[])
     LOG_D ("workbench refcount: " <<  (int) s_workbench->get_refcount (),
            "refcount-domain");
 
-    if (process_gui_command_line (a_argc, a_argv, retval) != true) {
+    if (process_gui_options (a_argc, a_argv) != true) {
         return -1;
     }
 
     //intercept ctrl-c/SIGINT
     signal (SIGINT, sigint_handler);
+
+    if (gv_use_launch_terminal) {
+        // So the user wants the inferior to use the terminal Nemiver was
+        // launched from, for input/output.
+        //
+        // Letting the inferior use the terminal from which Nemiver was
+        // launched from implies calling the "set inferior-tty" GDB command,
+        // when we are using the GDB backend.
+        // That command is implemented using the TIOCSCTTY ioctl. It sets the
+        // terminal as the controlling terminal of the inferior process. But that
+        // ioctl requires (among other things) that the terminal shall _not_ be
+        // the controlling terminal of any other process in another process
+        // session already. Otherwise, GDB spits the error:
+        // "GDB: Failed to set controlling terminal: operation not
+        // permitted"
+        // The problem is, Nemiver itself uses that terminal as a
+        // controlling terminal. So Nemiver itself must relinquish its
+        // controlling terminal to avoid letting the ioctl fail.
+        // We do so by calling the setsid function below.
+        // The problem is that setsid will fail with EPERM if Nemiver is
+        // started as a process group leader already.
+        // Trying ioctl (tty_fd, TIOCNOTTY, 0) does not seem to properly
+        // disconnect Nemiver from its terminal either. Sigh.
+        setsid ();
+    }
+
     gtk_kit.run (s_workbench->get_root_window ());
 
     NEMIVER_CATCH_NOX
